wcwidth.ucd

Unicode Character Database (UCD) support namespace. This is not part of the public API of clj-wcwidth and may change in any way, at any time, without notice.

Unicode Character Database (UCD) support namespace.  This is not part of the
public API of clj-wcwidth and may change in any way, at any time, without
notice.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries