wcwidth.ucd

Unicode Character Database (UCD) support namespace. This is not part of the public API of clj-wcwidth and may change in any way, at any time, without notice.

Unicode Character Database (UCD) support namespace.  This is not part of the
public API of clj-wcwidth and may change in any way, at any time, without
notice.
raw docstring

combining-class-rangesclj

source

control-rangesclj

source

emoji-sequences-setclj

source

in-ranges?clj

(in-ranges? ranges code-point)

Is the given code-point in any of the given ranges?

Is the given code-point in any of the given ranges?
sourceraw docstring

is-zwj-emoji-sequence?clj

Is the given sequence of codepoints a ZWJ emoji?

Is the given sequence of codepoints a ZWJ emoji?
sourceraw docstring

wide-rangesclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries