The public API of clj-wcwidth.
The public API of [`clj-wcwidth`](https://github.com/pmonks/clj-wcwidth).
Unicode Character Database (UCD) support namespace. This is not part of the public API of clj-wcwidth and may change in any way, at any time, without notice.
Unicode Character Database (UCD) support namespace. This is not part of the public API of clj-wcwidth and may change in any way, at any time, without notice.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |