Unicode Character Database (UCD) support namespace. This is not part of the public API of clj-wcwidth and may change in any way, at any time, without notice.
Unicode Character Database (UCD) support namespace. This is not part of the public API of clj-wcwidth and may change in any way, at any time, without notice.
(in-ranges? ranges code-point)Is the given code-point in any of the given ranges?
Is the given code-point in any of the given ranges?
Is the given sequence of codepoints a ZWJ emoji?
Is the given sequence of codepoints a ZWJ emoji?
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |